Index: src/debug/debug-scopes.h |
diff --git a/src/debug/debug-scopes.h b/src/debug/debug-scopes.h |
index 80e19810e742f897731e9f80394304e6afba0207..e317082cb808dc0c5a3585aa00ee2749b7245887 100644 |
--- a/src/debug/debug-scopes.h |
+++ b/src/debug/debug-scopes.h |
@@ -75,8 +75,8 @@ class ScopeIterator { |
// be an actual context. |
Handle<Context> CurrentContext(); |
- // Populate the list with collected non-local variable names. |
- void GetNonLocals(List<Handle<String> >* list_out); |
+ // Populate the dictionary with collected non-local variable names. |
+ Handle<NameDictionary> GetNonLocals(); |
bool ThisIsNonLocal(); |